.. IOGraph documentation master file, created by
   sphinx-quickstart on Thu Jul 15 17:28:11 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to IOGraph's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. argparse::
   :module: IOGraph
   :func: my_func_that_returns_a_parser
   :prog: fancytool

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
